@@ -2,7 +2,7 @@ from django import http
 from django.contrib.auth.models import User, Permission
 from django.test import TestCase, override_settings
 from django.test.client import RequestFactory
-from django.urls import path
+from django.urls import path, include
 
 from django_early_return import EarlyReturn
 
@@ -16,6 +16,7 @@ def raise_not_allowed(request):
     not_currently_allowed(request, 'registration is not yet open')
 
 urlpatterns = [
+    path('', include('qnc_crud.urls')),
     path('check_for_delete_user', check_for_delete_user),
     path('not_currently_allowed', not_currently_allowed),
 ]
@@ -52,4 +53,4 @@ class PermissionsTestCase(TestCase):
         self.assertEqual(response.status_code, 200)
 
     def test_perm_funcs_can_be_imported_from_qnc_crud(self):
-        from qnc_crud import assert_permission, not_currently_allowed
\ No newline at end of file
+        from qnc_crud import login_required, assert_permission, not_currently_allowed
\ No newline at end of file
